@@ -1,22 +1,17 @@
 #!/usr/bin/python3
 
-from __future__ import annotations
 from datetime import datetime
+from dataclasses import dataclass
 
 
+@dataclass
 class Friend:
     '''
         Data class for holding information related to a facebook friend
         i.e. friend name and when these two became friend
     '''
-
-    def __init__(self, name: str, time: int):
-        self._name = name
-        self._time = time
-
-    @property
-    def name(self) -> str:
-        return self._name
+    name: str
+    _time: int
 
     @property
     def time(self) -> datetime:
