@@ -122,8 +122,7 @@ def plotWeeklyHeatMapWithLikesReactionsComments(reactions: Reactions, comments:
         plt.close(_fig)
 
         return True
-    except Exception as e:
-        print(e)
+    except Exception:
         return False
 
 
